SystemOrganization addCategory: #ReleaseBuilder!

Object subclass: #ReleaseBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilder commentStamp: 'bp 12/4/2009 10:39' prior: 0!
I'm responsible to help people releasing various distributions of Squeak.!

!ReleaseBuilder methodsFor: 'utilities' stamp: 'ar 9/27/2005 20:10'!
cleanUpChanges
	"Clean up the change sets"

	"ReleaseBuilder new cleanUpChanges"
	
	| projectChangeSetNames |

	"Delete all changesets except those currently used by existing projects."
	projectChangeSetNames := Project allSubInstances collect: [:proj | proj changeSet name].
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs | (projectChangeSetNames includes: cs) not].
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/26/2004 15:28'!
cleanUpEtoys
	"ReleaseBuilder new cleanUpEtoys"


	StandardScriptingSystem removeUnreferencedPlayers.

	(self confirm: 'Remove all projects and players?')
		ifFalse: [^self].
	Project removeAllButCurrent.

	#('Morphic-UserObjects' 'EToy-UserObjects' 'Morphic-Imported' )
		do: [:each | SystemOrganization removeSystemCategory: each]! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/26/2004 15:33'!
finalCleanup
	"ReleaseBuilder new finalCleanup"


	Smalltalk forgetDoIts.

	DataStream initialize.
	Behavior flushObsoleteSubclasses.

	"The pointer to currentMethod is not realy needed (anybody care to fix this) and often holds on to obsolete bindings"
	MethodChangeRecord allInstancesDo: [:each | each noteNewMethod: nil].

	self cleanUpEtoys.
	SmalltalkImage current fixObsoleteReferences.

	Smalltalk flushClassNameCache.
	3 timesRepeat: [
		Smalltalk garbageCollect.
		Symbol compactSymbolTable.
	].
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:41'!
finalStripping
	"ReleaseBuilder new finalStripping"
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'nice 1/1/2010 21:55'!
fixObsoleteReferences
	"ReleaseBuilder new fixObsoleteReferences"

	
	Preference allInstances do: [:each | | informee | 
		informee := each instVarNamed: #changeInformee.
		((informee isKindOf: Behavior)
			and: [informee isObsolete])
			ifTrue: [
				Transcript show: each name; cr.
				each instVarNamed: #changeInformee put: (Smalltalk at: (informee name copyReplaceAll: 'AnObsolete' with: '') asSymbol)]].
 
	CompiledMethod allInstances do: [:method |
		| obsoleteBindings |
		obsoleteBindings := method literals select: [:literal |
			literal isVariableBinding
				and: [literal value isBehavior
				and: [literal value isObsolete]]].
		obsoleteBindings do: [:binding |
			| obsName realName realClass |
			obsName := binding value name.
			Transcript show: obsName; cr.
			realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
			realClass := Smalltalk at: realName asSymbol ifAbsent: [UndefinedObject].
			binding isSpecialWriteBinding
				ifTrue: [binding privateSetKey: binding key value: realClass]
				ifFalse: [binding key: binding key value: realClass]]].


	Behavior flushObsoleteSubclasses.
	Smalltalk garbageCollect; garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [SystemNavigation default inspect]! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'ar 9/27/2005 21:44'!
initialCleanup
	"Perform various image cleanups in preparation for making a Squeak gamma release candidate image."
	"ReleaseBuilder new initialCleanup"
	
	Undeclared removeUnreferencedKeys.
	StandardScriptingSystem initialize.

	(Object classPool at: #DependentsFields) size > 1 ifTrue: [self error:'Still have dependents'].
	Undeclared isEmpty ifFalse: [self error:'Please clean out Undeclared'].

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ScriptingSystem deletePrivateGraphics.  "?"
	
	self cleanUpChanges.
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.

	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.

	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Smalltalk garbageCollect.
	
	SMSqueakMap default purge.
	
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 16:25'!
installPreferences
	Preferences initialize.
	Preferences chooseInitialSettings.
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/26/2004 11:02'!
installReleaseSpecifics
	"ReleaseBuilder new installReleaseSpecifics"
! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:53'!
installVersionInfo
	"ReleaseBuilder new installVersionInfo"
! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'sd 9/26/2004 13:35'!
makeSqueaklandRelease
	"ReleaseBuilder new makeSqueaklandRelease"

	self 
		makeSqueaklandReleasePhasePrepare; 		makeSqueaklandReleasePhaseStripping; 		makeSqueaklandReleasePhaseFinalSettings; 		makeSqueaklandReleasePhaseCleanup! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'ar 9/27/2005 21:45'!
makeSqueaklandReleasePhaseCleanup
	"ReleaseBuilder new makeSqueaklandReleasePhaseCleanup"

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ChangeSet 
		removeChangeSetsNamedSuchThat: [:cs | cs name ~= ChangeSet current name].
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.
	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	"Remove existing player references"
	References keys do: [:k | References removeKey: k].
	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors isEmpty 
		ifFalse: [self error: 'Still have obsolete behaviors'].

	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	Smalltalk fixObsoleteReferences.
	Smalltalk abandonTempNames.
	Smalltalk zapAllOtherProjects.
	Smalltalk forgetDoIts.
	Smalltalk flushClassNameCache.
	3 timesRepeat: 
			[Smalltalk garbageCollect.
			Symbol compactSymbolTable]! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'md 2/24/2006 15:18'!
makeSqueaklandReleasePhaseFinalSettings
	"ReleaseBuilder new makeSqueaklandReleasePhaseFinalSettings"

	| serverName serverURL serverDir updateServer highestUpdate newVersion |

	ProjectLauncher splashMorph: (FileDirectory default readOnlyFileNamed: 'scripts\SqueaklandSplash.morph') fileInObjectAndCode.

	"Dump all morphs so we don't hold onto anything"
	World submorphsDo:[:m| m delete].

	#(
		(honorDesktopCmdKeys false)
		(warnIfNoChangesFile false)
		(warnIfNoSourcesFile false)
		(showDirectionForSketches true)
		(menuColorFromWorld false)
		(unlimitedPaintArea true)
		(useGlobalFlaps false)
		(mvcProjectsAllowed false)
		(projectViewsInWindows false)
		(automaticKeyGeneration true)
		(securityChecksEnabled true)
		(showSecurityStatus false)
		(startInUntrustedDirectory true)
		(warnAboutInsecureContent false)
		(promptForUpdateServer false)
		(fastDragWindowForMorphic false)

		(externalServerDefsOnly true)
		(expandedFormat false)
		(eToyFriendly true)
		(eToyLoginEnabled true)
		(magicHalos true)
		(mouseOverHalos true)
		(biggerHandles false)
		(selectiveHalos true)
		(includeSoundControlInNavigator true)
		(readDocumentAtStartup true)
		(preserveTrash true)
		(slideDismissalsToTrash true)

	) do:[:spec|
		Preferences setPreference: spec first toValue: spec last].
	"Workaround for bug"
	Preferences enable: #readDocumentAtStartup.

	World color: (Color r: 0.9 g: 0.9 b: 1.0).

	"Clear all server entries"
	ServerDirectory serverNames do: [:each | ServerDirectory removeServerNamed: each].
	SystemVersion current resetHighestUpdate.

	"Add the squeakalpha update stream"
	serverName := 'Squeakalpha'.
	serverURL := 'squeakalpha.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'updates/';
		altUrl: serverDir;
		user: 'sqland';
		password: nil.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

	"Add the squeakland update stream"
	serverName := 'Squeakland'.
	serverURL := 'squeakland.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'public_html/updates/';
		altUrl: serverDir.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' initialAnswer: 'Squeakland 3.8.' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	(self confirm: self version , '
Is this the correct version designation?
If not, choose no, and fix it.') ifFalse: [^ self].
! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'ar 9/27/2005 21:45'!
makeSqueaklandReleasePhasePrepare
	"ReleaseBuilder new makeSqueaklandReleasePhasePrepare"

	Undeclared removeUnreferencedKeys.
	StandardScriptingSystem initialize.
	Preferences initialize.
	"(Object classPool at: #DependentsFields) size > 1 ifTrue: [self error:'Still have dependents']."
	Undeclared isEmpty ifFalse: [self error:'Please clean out Undeclared'].

	"Dump all projects"
	Project allSubInstancesDo:[:prj| prj == Project current ifFalse:[Project deletingProject: prj]].

	"Set new look so we don't need older fonts later"
	StandardScriptingSystem applyNewEToyLook.

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ScriptingSystem deletePrivateGraphics.
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs| cs name ~= ChangeSet current name].
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.
	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	"Remove existing player references"
	References keys do:[:k| References removeKey: k].

	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Smalltalk garbageCollect.
! !

!ReleaseBuilder methodsFor: 'squeakland' stamp: 'ul 1/11/2010 07:20'!
makeSqueaklandReleasePhaseStripping
	"ReleaseBuilder new makeSqueaklandReleasePhaseStripping"

	#(#Helvetica #Palatino #Courier #ComicSansMS )
		do: [:n | TextConstants
				removeKey: n
				ifAbsent: []].
	Smalltalk
		at: #Player
		ifPresent: [:superCls | superCls
				allSubclassesDo: [:cls | 
					cls isSystemDefined
						ifFalse: [cls removeFromSystem].
					cls := nil]].
	Smalltalk garbageCollect.
	Smalltalk discardFFI; discardSUnit; discardSpeech.
	"discardMVC;"
	SystemOrganization removeEmptyCategories.
	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Behavior flushObsoleteSubclasses.
	Smalltalk garbageCollect; garbageCollect.
	DataStream initialize.
	Smalltalk fixObsoleteReferences! !

!ReleaseBuilder methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:58'!
prepareReleaseImage
	"Perform various image cleanups in preparation for making a Squeak gamma release candidate image."
	"ReleaseBuilder new prepareReleaseImage"
	
	(self confirm: 'Are you sure you want to prepare a release image?
This will perform several irreversible cleanups on this image.')
		ifFalse: [^ self].

	self
		initialCleanup;
		installPreferences;
		finalStripping;
		installReleaseSpecifics;
		finalCleanup;
		installVersionInfo
! !

ReleaseBuilder subclass: #ReleaseBuilderDeveloper
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderDeveloper commentStamp: 'gk 2/28/2005 13:27' prior: 0!
This release builder subclass is used for the official Squeak distribution Basic, which currently is the base image of Squeak.
Full is then built on top of Basic using a loadscript from SqueakMap. Minimal is constructed using another script from SqueakMap that removes packages that are included in Basic.!

!ReleaseBuilderDeveloper methodsFor: 'utilities' stamp: 'mir 11/26/2004 16:18'!
cleanUpChanges
	"Clean up the change sets"

	"ReleaseBuilderDeveloper new cleanUpChanges"
	
! !

!ReleaseBuilderDeveloper methodsFor: 'utilities' stamp: 'mir 4/7/2005 11:56'!
installPreferences
	super installPreferences.
	#(
		(updateFromServerAtStartup true)

	) do:[:spec|
		Preferences setPreference: spec first toValue: spec last]! !

!ReleaseBuilderDeveloper methodsFor: 'utilities' stamp: 'stephaneducasse 2/3/2006 22:23'!
installReleaseSpecifics
	"Currently just clear and add the ServerDirectories
	and update streams we want as default."

	"Clear all server entries"
	ServerDirectory serverNames do: [:each | ServerDirectory removeServerNamed: each].

	"Add default entries, added an entry for the new file area.
	The others are the current ones that see to work 
	as of 2005-02-28 and I recreated them using source."
	ServerDirectory addServer: (ServerDirectory new 
		type: #ftp;
		user: '';
		server: 'box1.squeakfoundation.org';
		altUrl: 'http://box1.squeakfoundation.org/files';
		directory: 'files';
		keepAlive: false) named: 'Squeak.org Archive'.
	ServerDirectory addServer: (ServerDirectory new 
		type: #ftp;
		server: 'st.cs.uiuc.edu';
		user: 'anonymous';
		directory: '/Smalltalk/Squeak';
		keepAlive: false) named: 'UIUC Archive'.	
	ServerDirectory addServer: (ServerDirectory new 
		type: #ftp;
		server: 'ftp.create.ucsb.edu';
		user: 'anonymous';
		directory: '/pub/Smalltalk/Squeak';
		keepAlive: false) named: 'UCSBCreate Archive'.
	ServerDirectory addServer: SuperSwikiServer defaultSuperSwiki named: 'Bob SuperSwiki'.
	ServerDirectory addServer: (SuperSwikiServer new 
		type: #http;
		server: 'squeakland.org:8080';
		altUrl: 'http://www.squeakland.org/uploads';
		directory: '/super/SuperSwikiProj';
		keepAlive: false;
		acceptsUploads: true) named: 'Squeakland SuperSwiki'.
	ServerDirectory addServer: (HTTPServerDirectory new 
		type: #ftp;
		user: 'sqland';
		server: 'www.squeakland.org';
		altUrl: 'http://www.squeakland.org/projects';
		directory: 'projects';
		keepAlive: false) named: 'Squeakland Projects'.

"Add the update streams here just as Squeakland does?
	serverName := 'Squeakland'.
	serverURL := 'squeakland.org'.
	serverDir := serverURL , '/'.
	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'public:=html/updates/';
		altUrl: serverDir.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.
"
! !

ReleaseBuilder subclass: #ReleaseBuilderFor3dot10
	instanceVariableNames: 'repository packagesList mantisNo'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

ReleaseBuilderFor3dot10 class
	instanceVariableNames: 'current'!

!ReleaseBuilderFor3dot10 commentStamp: 'edc 4/5/2007 10:06' prior: 0!
This class has two functions.  One is to hold a few methods that are used by the release team to make an initial or a final release.  These will not be used much.  The other is to manage the update stream.  In general, an update will be a set of Montecello versions.  There will be a "packages" method that lists them, and an "update" method that loads them.  The actual update file will just load these two methods from Montecello and execute them.

Once the 3.10 release cycle is over, this class will be useless except for tracking history.

For do a new update:
With a regular web browser like Firefox you go to http://bugs.squeak.org/view.php?id= nnnn
If you think what this should go into image, then in a Workspace do

Installer mantis createRBforBug: nnnn !

ReleaseBuilderFor3dot10 class
	instanceVariableNames: 'current'!

!ReleaseBuilderFor3dot10 class methodsFor: 'instance creation' stamp: 'edc 4/1/2007 08:32'!
clear

" ReleaseBuilderFor3dot10 clear "
	current:= nil! !

!ReleaseBuilderFor3dot10 class methodsFor: 'instance creation' stamp: 'edc 4/1/2007 08:33'!
current

" ReleaseBuilderFor3dot10 current inspect "
	^current ifNil: [current := (self new) newUpdate]! !

!ReleaseBuilderFor3dot10 methodsFor: 'managing updates' stamp: 'edc 4/5/2007 10:18'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	^pa workingCopy repositoryGroup
! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'rej 1/29/2007 22:27'!
advanceToThreeDotTenAlpha

"Offer the chance to advance the version number."
(self confirm: 'There are no further updates for Squeak 3.9.
Do you wish to advance to version 3.10alpha?
[Yes] Your system will be marked as 3.10alpha, and you will
subsequently receive ''test pilot'' updates for 3.10.
[No] Your system will be marked as 3.9, allowing you
to receive only final fixes for the 3.9 stable release.
[Neither] You may choose No, and immediately quit without saving,
allowing you to make a backup copy before adopting this change.
DO YOU WANT TO ADVANCE to Version 3.10alpha now?')
	ifTrue: [SystemVersion newVersion: 'Squeak3.10alpha'.
			SystemVersion current date: Time now asDate.
			self inform: 'You may now save this Version 3.10alpha image
and retrieve updates again for 3.10alpha and beyond.']
	ifFalse: [SystemVersion current version: 'Squeak3.9'; date: Time now asDate..
			self inform: 'You may now save this Version 3.9 final image
and retrieve updates again for any final fixes to 3.9.
- - - - -
(If you quit without saving now, your image will revert to
3.9without any of the updates you just loaded)']! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 4/5/2007 07:11'!
cleanUnwantedCs
	ChangeSet 
		removeChangeSetsNamedSuchThat: [:cs | cs name ~= ChangeSet
current name].
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'rej 1/29/2007 21:33'!
createBackgroundColor
| gf |
gf := GradientFillStyle  ramp: {0.0->(Color r: 0.97 g: 0.98 b: 1.0) .
1.0->(Color r: 0.0 g: 0.658 b: 0.474)}.
	gf	origin: 0 @ 0;
		direction: 0@400;
		normal: 640@0;
		radial: false.
World fillStyle: gf

! !

!ReleaseBuilderFor3dot10 methodsFor: 'managing updates' stamp: 'ar 12/31/2009 15:13'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.
	
	"Initialization required for tests: strange why this is not a teardwon method"
	Smalltalk at: #SendCaches ifPresent:[:aClass| aClass initializeAllInstances].! !

!ReleaseBuilderFor3dot10 methodsFor: 'packages' stamp: 'edc 2/26/2007 16:30'!
installInBoxAnd310
	
	
	MCWorkingCopy allManagers do: [:each | 
		each  repositoryGroup
			addRepository: (MCHttpRepository new location: 'http://source.squeakfoundation.org/310' ; user: 'squeak'; password: 'squeak');
			addRepository: (MCHttpRepository new location: 'http://source.squeakfoundation.org/inbox' ; user: '' ; password: '')].! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 9/1/2007 10:07'!
loadLast: aPackageName
| package |
package := self repository readableFileNames detect:[:ea| ea beginsWith: aPackageName] ifNone:[]. package ifNotNil: [
	(repository  loadVersionFromFileNamed: package) load]
ifNil: [ ^ self error: aPackageName ,' is not on this repository '].
! !

!ReleaseBuilderFor3dot10 methodsFor: 'packages' stamp: 'nice 12/27/2009 03:11'!
loadLastVersion: aListOfPackageNames 
| mcw montiNames version |
mcw := MCWorkingCopyBrowser new repository: (MCHttpRepository
				location: 'http://source.squeakfoundation.org/39a'
				user: ''
				password: '').
mcw repository ifNotNil: [:repos | montiNames := repos readableFileNames ].
	
	aListOfPackageNames do: [:mo | | package |
	
	package := (montiNames detect:[:ea| ea beginsWith: mo] ifNone:[] ) .
	package ifNotNil: [
	version := mcw repository loadVersionFromFileNamed: package.
	version load]].
^version! !

!ReleaseBuilderFor3dot10 methodsFor: 'managing updates' stamp: 'edc 6/24/2007 10:07'!
loadPackages: packageNames
	self loadTogether: (packageNames findTokens: ' ', String cr) merge: false! !

!ReleaseBuilderFor3dot10 methodsFor: 'managing updates' stamp: 'edc 8/21/2007 15:29'!
loadTogether: aCollection merge: aBoolean
	| loader mcc |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	aCollection do: [:eachVersion | self addRepositoryToPackageNamed: (eachVersion copyUpTo: $- )].
	(self newerVersionsIn: aCollection)
		do: [:fn | Transcript show: fn;cr.
			loader addVersion: (self repository loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader load].
		SystemNavigation default obsoleteBehaviors size > 0
        ifTrue: [
            SystemNavigation default obsoleteBehaviors inspect.
            self error:'The changes should be reviewed'].
self flushCaches.

mcc := MCWorkingCopyBrowser new.
mcc  repository: MCCacheRepository default.
mcc workingCopies select:
		[:wc |
		(wc modified = true)] thenDo: [:ea| 
		mcc workingCopy: ea.
		ea modified: false
		 ]

! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 2/27/2007 07:20'!
makeSqueakRelease
	| monti |
		
	self unloadSome.
	
	monti := MCWorkingCopyBrowser new.
	monti unsortedWorkingCopies
		do: [:ea | ((PackageOrganizer default packageNames) includes: (ea package name)) ifFalse:[ ea unregister]].
	monti flushAllCaches.
	
	
	3
		timesRepeat: [Smalltalk garbageCollect].
	DataStream initialize.
	Flaps replaceGlobalFlapwithID: 'Tools' translated.
	Flaps replaceGlobalFlapwithID: 'Widgets' translated.
	self cleanUpEtoys.
	SmalltalkImage current fixObsoleteReferences.
	
	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Behavior flushObsoleteSubclasses.
	3
		timesRepeat: [Smalltalk garbageCollect]! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 3/8/2007 09:24'!
makeSqueakThreeTenRelease
	"ReleaseBuilderFor3dot10 new makeSqueakThreeTenRelease"

	self 
		makeSqueakThreeTenReleasePhasePrepare;
		makeSqueakRelease; 		
		makeSqueakThreeTenReleasePhaseCleanup;
		installInBoxAnd310;
	updateFrom7067;
		createBackgroundColor! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 4/6/2007 06:57'!
makeSqueakThreeTenReleasePhaseCleanup
	"ReleaseBuilderFor3dot10 new makeSqueakThreeTenReleasePhaseCleanup"
| newVersion |
	Smalltalk at: #Browser ifPresent:[:br| br initialize].
self cleanUnwantedCs.
	"Remove existing player references"
	References keys do: [:k | References removeKey: k].
	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Behavior flushObsoleteSubclasses.
	SystemNavigation default obsoleteBehaviors isEmpty 
		ifFalse: [self error: 'Still have obsolete behaviors'].

	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	self fixObsoleteReferences.
	"Smalltalk abandonTempNames."
	Smalltalk zapAllOtherProjects.
	Smalltalk forgetDoIts.
	Smalltalk flushClassNameCache.
	3 timesRepeat: 
			[Smalltalk garbageCollect.
			Symbol compactSymbolTable].
"SystemVersion current registerUpdate: 7069." "We only need for when start the release"
	newVersion := 'Squeak3.10alpha.' , SystemVersion current
highestUpdate printString. 

	
	newVersion := newVersion ,'.'.
	(SourceFiles at: 2) ifNotNil:
		[SmalltalkImage current closeSourceFiles; "so copying the
changes file will always work"
			 saveChangesInFileNamed: (SmalltalkImage current
fullNameForChangesNamed: newVersion)].
	SmalltalkImage current saveImageInFileNamed: (SmalltalkImage current
fullNameForImageNamed: newVersion)
		! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 4/5/2007 07:12'!
makeSqueakThreeTenReleasePhasePrepare
	"ReleaseBuilderFor3dot10 new makeSqueakThreeTenReleasePhasePrepare"

	Undeclared removeUnreferencedKeys.
	StandardScriptingSystem initialize.
	Preferences initialize.
	"(Object classPool at: #DependentsFields) size > 1 ifTrue: [self
error:'Still have dependents']."
	Undeclared isEmpty ifFalse: [self error:'Please clean out
Undeclared'].

	"Dump all projects"
	Project allSubInstancesDo:[:prj| prj == Project current
ifFalse:[Project deletingProject: prj]].

	"Set new look so we don't need older fonts later"
	StandardScriptingSystem applyNewEToyLook.

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ScriptingSystem deletePrivateGraphics.
	self cleanUnwantedCs.
	"Reinitialize DataStream; it may hold on to some zapped entitities"
	DataStream initialize.
	"Remove existing player references"
	References keys do:[:k| References removeKey: k].

	Smalltalk garbageCollect.
	ScheduledControllers := nil.
	Smalltalk garbageCollect.
! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 4/1/2007 08:22'!
newUpdate
packagesList := Set new! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 5/15/2007 08:03'!
newUpdateFor: aBugNo
"  ReleaseBuilderFor3dot10 new  newUpdateFor: nnnn"
|cs updateNo  newName newSet lastName|
mantisNo := aBugNo.
updateNo := SystemVersion current highestUpdate + 1.

lastName := ChangeSet allChangeSetNames last.
	newName _ UIManager default
		request: 'Please name the new change set:'
		initialAnswer: updateNo asString, lastName.
	newName isEmptyOrNil ifTrue:
		[^ nil].
	newSet _ ChangeSet basicNewChangeSet: newName.
	newSet ifNotNil:
		[ChangeSet  newChanges: newSet].
	

cs := newSet .
cs preamble:  '"',(Installer mantis preambleCsForRB: aBugNo) withSqueakLineEndings asUnHtml , '"'.
cs postscript: '"', self postcriptTemplate, aBugNo asString, '"

ReleaseBuilderFor3dot10 new updatePackages: '.
self updateToNext.
cs editPostscript! !

!ReleaseBuilderFor3dot10 methodsFor: 'managing updates' stamp: 'rej 1/29/2007 21:49'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ReleaseBuilderFor3dot10 methodsFor: 'packages' stamp: 'muOuser 3/11/2007 10:06'!
packages7067
	^ 'System-edc.102(sd.101).mcd
Tests-edc.20(sd.19).mcd
Kernel-edc.151(sd.150).mcd
ST80-edc.38.mcz
Monticello-edc.311.mcz
CollectionsTests-edc.35.mcz
Graphics-edc.40(ar.39).mcd
SystemChangeNotification-Tests-edc.7.mcz
GraphicsTests-edc.10(ar.9).mcd
SMBase-edc.86(sd.85).mcd
KernelTests-edc.51(sd.50).mcd
Traits-edc.226.mcz
Files-edc.20.mcz
ToolBuilder-Kernel-rej.18.mcz
XML-Parser-mir.3.mcz
Universes-ls.19.mcz'! !

!ReleaseBuilderFor3dot10 methodsFor: 'packages' stamp: 'nice 12/27/2009 04:07'!
packagesInfluenced

" This is a partial response to Ralph request.
Lets know what packages could touch some code file what we wish go into image.
Intended to load Mantis fix and convert the result to Monticello "
"
ReleaseBuilderFor3dot10 new packagesInfluenced
 "
| monti fileName cs |
monti := Set new.
fileName := UIManager default chooseFileMatching: #('st' 'cs').
cs := FilePackage fromFileNamed: fileName.
cs classes do: [:cl| | realClass cat p |
	realClass := Smalltalk at: cl name ifAbsent: [ self error: 'This image do not have ', cl asString] .cat := (realClass category findTokens: '-') first.
    
    p := (PackageInfo allPackages collect:[:pi| pi packageName]) .
    (p includes: cat) ifTrue:[ monti add: cat]].
^ monti.! !

!ReleaseBuilderFor3dot10 methodsFor: 'packages' stamp: 'nice 12/27/2009 04:07'!
packagesInfluenced: aStream named: aFileName

" This is a partial response to Ralph request.
Lets know what packages could touch some code file what we wish go into image.
Intended to load Mantis fix and convert the result to Monticello "
"
ReleaseBuilderFor3dot10 new packagesInfluenced
 "
| monti cs |
monti := Set new.

cs := FilePackage new fromStream: aStream reset named: aFileName.
cs classes do: [:cl| | p realClass cat |
	realClass := Smalltalk at: cl name ifAbsent: [ self error: 'This image do not have ', cl asString] .cat := (realClass category findTokens: '-') first.
    
    p := (PackageInfo allPackages collect:[:pi| pi packageName]) .
    (p includes: cat) ifTrue:[ monti add: cat]].
packagesList addAll:  monti.! !

!ReleaseBuilderFor3dot10 methodsFor: 'accessing' stamp: 'nice 12/27/2009 04:07'!
packagesList
 | mcc lista |
lista := OrderedCollection new.
mcc := MCWorkingCopyBrowser new.
mcc  repository: MCCacheRepository default.
lista := mcc workingCopies select:
		[:wc |
		((wc modified = true) & wc ancestors notEmpty)] thenCollect: [:ea| | packName pos| 
		packName := ea  ancestry ancestors first name.
		pos := packName indexOf: $-.
		packName := packName copyFrom: 1 to: pos -1.
		lista add: packName].
	^ lista! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 4/1/2007 10:44'!
postcriptTemplate
^'To follow this see
http://bugs.squeak.org/view.php?id= '! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'rej 3/5/2007 09:05'!
repository 
  repository isNil ifTrue: [
		repository := MCHttpRepository
                location: 'http://source.squeakfoundation.org/310'
                user: ''
                password: ''.].
  ^repository! !

!ReleaseBuilderFor3dot10 methodsFor: 'packages' stamp: 'edc 7/24/2007 07:41'!
saveNewVersion: v

v repositoryGroup: (self addRepositoryToPackageNamed: v package name).
repository user ifEmpty:[
repository user:  (UIManager default request: '3.10 Repository username').
repository	password: (UIManager default request: '3.10 Repository  password')].

repository storeVersion:  (v newVersionWithName: v uniqueVersionName message: self postcriptTemplate, mantisNo asString)  .
! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 2/24/2007 12:01'!
testObsolete
"if we do some classes go, also his test should go"
^#(WatchMorphTest)! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 6/28/2007 07:42'!
unloadMorphicClasses

"These classes don't seem to be used, so unload them.  They always can be loaded later."

SystemOrganization classifyAll: #(BorderedStringMorph MouseActionIndicatorMorph CommandTilesMorph
TestClickExerciser SpectrumAnalyzerMorph FishEyeMorph SoundDemoMorph
MultiuserTinyPaint KidNavigationMorph CodecDemoMorph BlobMorph
 SoundMorph SubpaneDividerMorph
RolloverButtonMorph ClipboardMorph VeryPickyMorph
ClassRepresentativeMorph PhraseWrapperMorph WatchMorph
UpdatingTextMorph PluggableTabBarMorph PartsWindow HeadingMorph
ZoomMorph UpdatingStringMorphWithArgument SoundSequencerMorph
ImageMorphWithSpotlight TinyPaint InfoStringMorph
UpdatingBooleanStringMorph DrawErrorMorph ViewerRow
BalloonRectangleMorph  ViewerEntry MidiInputMorph
CachingMorph MovingEyeMorph MIDIPianoKeyboardMorph
DoubleClickExample MorphExample RulerMorph LabelStringMorph) under:
'Morphic-CandidatesForGo'.

(MCPackage named: 'Morphic-CandidatesForGo') unload .
#(TheWorldMenu FileServices AppRegistry Preferences FileList) do: [:cl|
(Smalltalk at: cl) removeObsolete].
self testObsolete do: [:cl|
Smalltalk removeClassNamed: cl].
3 timesRepeat: [Smalltalk garbageCollect].! !

!ReleaseBuilderFor3dot10 methodsFor: 'squeakThreeTen' stamp: 'edc 4/13/2007 18:46'!
unloadSome
	World removeAllMorphs.
	CommandHistory resetAllHistory.
	#('Flash' 'StarSqueak' 'SmaCC' 'Speech' 'Movies' 'FixUnderscores' 'OB' 'OmniBrowser' )
		do: [:ea | (MCPackage named: ea) unload.
			PackageOrganizer default unregisterPackageNamed: ea].
	#(#TheWorldMenu #FileServices #AppRegistry #Preferences #FileList )
		do: [:cl | (Smalltalk at: cl) removeObsolete].
		self unloadMorphicClasses.
	SystemOrganization removeEmptyCategories.
	! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'muOuser 3/11/2007 10:06'!
updateFrom7067
	"ReleaseBuilderFor3dot10 new updateFrom7067"
	self updatePackages: 'Monticello-rej.309.mcz'.
	"Enable atomic loading"
	self addRepositoryToPackageNamed: 'SystemChangeNotification-Tests'.
	self updatePackages: self packages7067.
	self flushCaches! !

!ReleaseBuilderFor3dot10 methodsFor: 'managing updates' stamp: 'rej 1/29/2007 21:58'!
updatePackages: packageNames
	self loadTogether: (packageNames findTokens: ' ', String cr) merge: true! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 3/16/2007 07:21'!
updateTo7070
^'EToys-edc.23(md.22).mcd'! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'edc 3/16/2007 07:26'!
updateTo7071
^'Collections-edc.72(md.71).mcd
CollectionsTests-edc.36(35).mcd
'! !

!ReleaseBuilderFor3dot10 methodsFor: 'updates' stamp: 'nice 12/27/2009 04:06'!
updateToNext

| stream mcc |
stream := RWBinaryOrTextStream on: String new.
mcc := MCWorkingCopyBrowser new.
mcc  repository: MCCacheRepository default.
mcc workingCopies select:
		[:wc |
		(wc modified = true)] thenDo: [:ea| | number p1 packString pos |
		self saveNewVersion: ea.
		
		packString :=  ea ancestry ancestorString .
		pos := packString indexOf: $..
		p1 := packString copyFrom: 1 to: pos -1.
		number := (packString copyFrom: pos + 1 to: packString size) asNumber.
		packString := p1 ,'.', number  asString , '(', (number - 1) asString ,').mcd'.
		packString := packString, Character cr asString.
		stream nextPutAll: packString
		].
ChangeSet current postscript: ChangeSet current postscript, stream contents! !

ReleaseBuilderFor3dot10 subclass: #ReleaseBuilderFor3dot11
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderFor3dot11 methodsFor: 'cleaning' stamp: 'edc 4/22/2008 07:40'!
cleanupPhaseFinal
" ReleaseBuilderFor3dot11 new cleanupPhaseFinal "
| tasks |
    tasks := OrderedCollection new
        
                add: [Smalltalk removeEmptyMessageCategories];
                add: [Workspace
                        allSubInstancesDo: [:each | each setBindings: Dictionary new]];
                add: [Undeclared removeUnreferencedKeys];
                add: [Categorizer sortAllCategories];
                add: [Symbol compactSymbolTable];
	add: [#(#TheWorldMenu #FileServices #AppRegistry #Preferences #FileList )
		do: [:cl | (Smalltalk at: cl) removeObsolete]]; add:[Flaps freshFlapsStart]; add:[MCFileBasedRepository flushAllCaches];
                 add: [HandMorph releaseCachedState;
	initForEvents.self fixObsoleteReferences];
                add: [Smalltalk forgetDoIts.

	DataStream initialize.
	Behavior flushObsoleteSubclasses.

	"The pointer to currentMethod is not realy needed (anybody care to fix this) and often holds on to obsolete bindings"
	MethodChangeRecord allInstancesDo: [:each | each noteNewMethod: nil].Smalltalk garbageCollectMost];
                 yourself.
Utilities
        informUserDuring: [:bar | tasks
                do: [:block |
                    bar value: block printString.
                    [block value]
                        on: Error
                        do: [:error | Transcript show: error;
                                 cr]]].
 SystemNavigation default obsoleteClasses isEmpty
        ifTrue: [SmalltalkImage current saveSession]
        ifFalse: [SystemNavigation default obsoleteClasses
                do: [:each | .self halt.[PointerFinder on: each]
                        on: Error
                        do: [:error | Transcript show: error; cr]]]


! !

!ReleaseBuilderFor3dot11 methodsFor: 'cleaning' stamp: 'ar 9/19/2009 20:19'!
cleanupPhasePrepare
self cleanUnwantedCs.
                "SMSqueakMap default clearCaches."
" Commented out for no Undeclared on image "
#(zapMVCprojects zapAllOtherProjects discardFlash discardFFI
computeImageSegmentation discardSpeech ) do:[:ea| 
SystemDictionary removeSelector:ea].
#( reserveUrl: saveAsResource saveDocPane saveOnURL saveOnURL:
saveOnURLbasic isTurtleRow objectViewed inATwoWayScrollPane) do:[:ea| 
Morph removeSelector: ea].

#(playfieldOptionsMenu presentPlayfieldMenu allScriptEditors
attemptCleanupReporting: modernizeBJProject
scriptorForTextualScript:ofPlayer:) do:[:ea| 
PasteUpMorph removeSelector:   ea].
#(isUniversalTiles noteDeletionOf:fromWorld: scriptorsForSelector:inWorld: tilesToCall: handMeTilesToFire) do:[:ea| 
Player removeSelector:   ea].
Player class removeCategory: 'turtles'.
Player removeCategory: 'slots-user'.
Morph removeCategory: 'scripting'.
ColorType removeCategory: 'tiles'.
TheWorldMainDockingBar removeSelector: #hideAllViewersIn: .
SystemOrganization removeCategoriesMatching: 'UserObjects'.
FileList2 class organization classify: #morphicViewOnDirectory: under: 'morphic ui'.
FileList2 class organization classify: #morphicView under: 'morphic ui'.
SystemOrganization classifyAll: #(AbstractMediaEventMorph ColorSwatch) under: 'MorphicExtras-AdditionalSupport'.! !

!ReleaseBuilderFor3dot11 methodsFor: 'squeakThreeEleven' stamp: 'edc 2/5/2008 07:21'!
createBackgroundColor
| gf |
gf := GradientFillStyle  ramp: {0.0->(Color r: 0.97 g: 0.98 b: 1.0) .
1.0->(Color r: 0.0 g: 0.658 b: 0.474)}.
	gf	origin: 0 @ 0;
		direction: 0@400;
		normal: 640@0;
		radial: false.
World fillStyle: gf! !

!ReleaseBuilderFor3dot11 methodsFor: 'sources managment' stamp: 'edc 2/16/2010 11:25'!
createCompressedSources
" ReleaseBuilderFor3dot11 new createCompressedSources"

ProtoObject allSubclassesWithLevelDo:[:cl :l| | dir | 
	dir := self createDirIfnotExists:cl category.
	
	
	Cursor write showWhile: [ | zipped nameToUse unzipped buffer |
		nameToUse :=  cl printString , FileDirectory dot, ImageSegment compressedFileExtension. 
		(dir fileExists: nameToUse) ifFalse:[
			unzipped :=RWBinaryOrTextStream on: ''.
			unzipped header; timeStamp.
	 cl  fileOutOn: unzipped moveSource: false toFile: 0.
	unzipped trailer.
	
			unzipped reset.
			zipped := dir newFileNamed: (nameToUse).
	zipped binary.
	zipped := GZipWriteStream on: zipped.
	buffer := ByteArray new: 50000.
	'Compressing ', nameToUse displayProgressAt: Sensor cursorPoint
		from: 0 to: unzipped size
		during:[:bar|
			[unzipped atEnd] whileFalse:[
				bar value: unzipped position.
				zipped nextPutAll: (unzipped nextInto: buffer)].
			zipped close.
			unzipped close]]]] startingLevel: 0! !

!ReleaseBuilderFor3dot11 methodsFor: 'sources managment' stamp: 'edc 2/12/2008 07:43'!
createDirIfnotExists: aDirName
(FileDirectory default directoryExists:aDirName)
		ifFalse: [FileDirectory default createDirectory: aDirName].
	^FileDirectory default directoryNamed: aDirName! !

!ReleaseBuilderFor3dot11 methodsFor: 'cleaning' stamp: 'edc 2/5/2008 07:33'!
getRidOfUnwantedMorphs
| objFl aButton  partBin unwantedMorph |
aButton _ SimpleButtonMorph new label: 'Tools'.
			aButton actWhen: #buttonDown.
objFl := Flaps globalFlapTabWithID: 'Objects'.
objFl referent showCategory: 'Tools' fromButton: aButton.
partBin := objFl referent submorphs at: 1.
unwantedMorph := partBin submorphThat: [:any| (any arguments at: 2) = 'SUnit Runner'] ifNone: [].
unwantedMorph delete.
2 timesRepeat: [unwantedMorph := partBin submorphThat: [:any| (any arguments at: 2) = 'Package Loader'] ifNone: []. "we have two of this "
unwantedMorph delete].
objFl := Flaps globalFlapTabWithID: 'Tools'.
partBin := objFl referent.
unwantedMorph := partBin submorphThat: [:any| (any arguments at: 2) = 'Package Loader'] ifNone: [].
unwantedMorph delete.
unwantedMorph := partBin submorphThat: [:any| (any arguments at: 2) = 'SUnit Runner'] ifNone: [].
unwantedMorph delete.! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 2/5/2008 07:56'!
groupingTests
" this is how I build Tests-edc.35 for unload "
| classList |

classList := OrderedCollection new.
	#(TestCase TestResource) do: [:cl|  (Smalltalk at:  cl)
		allSubclassesWithLevelDo: [:c :i | classList addFirst: c]
		startingLevel: 0].		
				 
	Smalltalk organization addCategory: 'Tests-Others'.
	 classList select: [:ea| ((ea basicCategory asString) beginsWith: 'Tests') not] thenDo: [:any|  SystemOrganization classify: any name under: 'Tests-Others']
	
! !

!ReleaseBuilderFor3dot11 methodsFor: 'updates' stamp: 'edc 7/16/2009 11:57'!
installtrunk

" ReleaseBuilderFor3dot11 new installtrunk"

	MCWorkingCopy allManagers
		do: [:each | each repositoryGroup addRepository: (MCHttpRepository new location: 'http://source.squeakfoundation.org/trunk/';
					 user: 'squeak';
					 password: 'squeak')]! !

!ReleaseBuilderFor3dot11 methodsFor: 'updates' stamp: 'nice 12/27/2009 03:11'!
loadLastVersion: aListOfPackageNames 
	| mcw montiNames version |
	mcw := MCWorkingCopyBrowser new
				repository: (MCHttpRepository
						location: 'http://source.squeakfoundation.org/trunk'
						user: ''
						password: '').
	mcw repository
		ifNotNil: [:repos | montiNames := repos readableFileNames].
	aListOfPackageNames
		do: [:mo | | package | 
			package := montiNames
						detect: [:ea | (ea findTokens: '-' ) first = mo]
						ifNone: [].
			package
				ifNotNil: [version := mcw repository loadVersionFromFileNamed: package.
					version load]].
	^ version! !

!ReleaseBuilderFor3dot11 methodsFor: 'squeakThreeEleven' stamp: 'edc 5/31/2008 10:09'!
makeSqueakThreeTenEleven
	"ReleaseBuilderFor3dot11 new makeSqueakThreeTenEleven"
	"World removeAllMorphs."
	Transcript open.
	self cleanupPhasePrepare;getRidOfUnwantedMorphs
	"prepareforUnloadBookMorphandFriends;"
	;prepareforUnloadEtoys;
	prepareforUnloadNebraska
	;groupingTests;
	unloadSomeMore;unloadSomeMore3;cleanupPhaseFinal;createBackgroundColor! !

!ReleaseBuilderFor3dot11 methodsFor: 'cleaning' stamp: 'edc 4/11/2008 04:41'!
prepareforUnloadBookMorphandFriends
SystemOrganization addCategory: #BookMorphandFriends.

SystemOrganization classifyAll: #( BookMorph BookPageSorterMorph BookPageThumbnailMorph BooklikeMorph FlexMorph FloatingBookControlsMorph KedamaMorph MethodMorph  MorphThumbnail   StoryboardBookMorph ) under: 'BookMorphandFriends'.
! !

!ReleaseBuilderFor3dot11 methodsFor: 'cleaning' stamp: 'edc 6/5/2008 08:08'!
prepareforUnloadEtoys
Smalltalk removeClassNamed: #FlexibleVocabulariesInfo.
SystemOrganization classifyAll: #(ActorState MethodMorph Player Presenter StickySketchMorph UnscriptedPlayer SlotInformation UnscriptedCardPlayer) under: 'MorphicExtras-EToys-Scripting'.
#( actorState actorState: isPartsDonor isPartsDonor: player player:) do: [:method|
MorphExtension organization classify: method under: '*MorphicExtras-accessing' suppressIfDefault: false].
HaloMorph organization classify: #doMakeSiblingOrDup:with: under: 'Old Etoys-handles'.
HaloMorph organization classify: #doDupOrMakeSibling:with: under: 'Old Etoys-handles'.
"self loadTogether: #('Morphic-CandidatesForGo-edc.3.mcz' ) merge: false."
SystemOrganization classifyAll: #(ScriptEditorMorph TwoWayScrollPane TabSorterMorph) under:
'Morphic-CandidatesForGo'.

#('*eToys-queries' '*eToys-eToy vocabularies' '*eToys-color' '*eToys-customevents-custom events' '*eToys-type vocabularies') do:[:ea| 
Vocabulary class removeCategory: ea].

#('*flexibleVocabularies-flexiblevocabularies-scripting' '*flexibleVocabularies-flexibleVocabularies' '*eToys-scripting' '*eToys-new-morph participation' '*eToys-customevents-user events') do:[:ea|
Morph class removeCategory:  ea].
#(nascentUserScriptInstance userScriptForPlayer: selector:  ) do:[:ea|
Player class removeSelector:  ea].
Smalltalk removeClassNamed: #FlexibleVocabulariesInfo.
Preferences removePreference: #allowEtoyUserCustomEvents. 
Morph organization classify: #partName:categories:documentation:sampleImageForm: under: '*MorphicExtras-new-morph participation'.
#(possiblyReplaceEToyFlaps twiddleSuppliesButtonsIn:) do: [:ea| 
Flaps class removeSelector:   ea].
Flaps clobberFlapTabList.
Flaps addStandardFlaps.
SystemOrganization classifyAll: #(ComponentLikeModel) under: 'MorphicExtras-Components'
! !

!ReleaseBuilderFor3dot11 methodsFor: 'cleaning' stamp: 'edc 2/15/2008 10:19'!
prepareforUnloadNebraska
SystemOrganization addCategory: #'Nebraska-Refactoring'.

SystemOrganization classifyAll: #(EToyGenericDialogMorph EToyProjectDetailsMorph EToyProjectHistoryMorph EToyProjectQueryMorph EToyProjectRenamerMorph EtoyUpdatingThreePhaseButtonMorph) under: 'Nebraska-Refactoring'.
WorldState organization classify: #remoteCanvasesDo: under: '*MorphicExtras-nebraska compatible'.
! !

!ReleaseBuilderFor3dot11 methodsFor: 'updates' stamp: 'edc 7/15/2009 17:02'!
repository
	repository isNil
		ifTrue: [repository := MCHttpRepository
						location: 'http://source.squeakfoundation.org/trunk/'
						user: ''
						password: ''].
	^ repository! !

!ReleaseBuilderFor3dot11 methodsFor: 'squeakThreeEleven' stamp: 'nice 12/27/2009 03:11'!
saveInTrunk: packageName 

" ReleaseBuilderFor3dot11 new saveInTrunk: Foo"
	| monti repo |
	monti := MCWorkingCopyBrowser new.
	repo := MCHttpRepository
				location: 'http://source.squeak.org/trunk'
				user: ''
				password: ''.
	
	
	(SystemOrganization categoriesMatching: packageName , '*')
		do: [:cat | 
			| workingCopy message | 
			PackageInfo registerPackageName: cat asString.
			workingCopy := MCWorkingCopy
						forPackage: (MCPackage new name: cat asString).
			workingCopy repositoryGroup addRepository: repo.
			repo user
				ifEmpty: [repo
						user: (UIManager default request: 'Trunk Repository username').
					repo
						password: (UIManager default request: 'Trunk Repository  password')].
				message := 	UIManager default 
			request: 'Please type comments for this package:' translated
			initialAnswer: 'a good comment' translated.
			
			repo
						storeVersion: (workingCopy newVersionWithName: workingCopy uniqueVersionName message: message)].
					
			monti workingCopyListChanged; changed: #workingCopySelection; changed: #repositoryList ! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 3/13/2008 10:29'!
unloadSomeMore
#('Tests' 'SMLoader' 'SMBase' 'SUnit' 'SUnitGUI' 'ScriptLoader' 'Universes' 'Installer' 'XML-Parser' )
		do: [:ea | (MCPackage named: ea) unload].
		self fixObsoleteReferences ! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 3/13/2008 10:29'!
unloadSomeMore2
"ReleaseBuilderFor3dot11 new unloadSomeMore2;cleanupPhaseFinal "
#('BookMorphandFriends'   )
		do: [:ea | (MCPackage named: ea) unload].self fixObsoleteReferences! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 5/31/2008 10:09'!
unloadSomeMore3
"ReleaseBuilderFor3dot11 new unloadSomeMore3;cleanupPhaseFinal;cleanUnwantedCs "
#('MorphicExtras-Demo'  'Morphic-CandidatesForGo' 'Nebraska' )
		do: [:ea | (MCPackage named: ea) unload].
		SystemOrganization removeCategoriesMatching: 'EToys*'.
		self fixObsoleteReferences! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 8/26/2009 10:21'!
unloadTraits
	"ReleaseBuilderFor3dot11 new unloadTraits"
	" self saveInLadrillos: 'Traits'."
	self unloadTraitsClearRefs.
	(MCPackage named: 'Traits') unload.
	self unloadTraitsTraitsStubs.
	self fixObsoleteReferences! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 6/2/2008 09:44'!
unloadTraitsClearRefs

| loader |
	loader _ CodeLoader new.
	loader baseURL:'http://installer.pbwiki.org/f/'.
	
	"Sources and segments can be loaded in parallel"
	loader loadSourceFiles: #('UnloadTraits-ClearRefs.cs' ).
	! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 6/2/2008 09:34'!
unloadTraitsStubOutAcessors

| loader |
	loader _ CodeLoader new.
	loader baseURL:'http://installer.pbwiki.org/f/'.
	
	"Sources and segments can be loaded in parallel"
	loader loadSourceFiles: #('UnloadTraits-StubOutAcessors.cs' ).
	! !

!ReleaseBuilderFor3dot11 methodsFor: 'unloadPackages' stamp: 'edc 6/2/2008 09:45'!
unloadTraitsTraitsStubs

| loader |
	loader _ CodeLoader new.
	loader baseURL:'http://installer.pbwiki.org/f/'.
	
	"Sources and segments can be loaded in parallel"
	loader loadSourceFiles: #('UnloadTraits-TraitsStubs.cs' ).
	! !

ReleaseBuilder subclass: #ReleaseBuilderNihongo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderNihongo methodsFor: 'release' stamp: 'md 2/24/2006 15:59'!
release
	"self release"
	
	Utilities emptyScrapsBook.

	Display setExtent: 960@720 depth: 16.
	World color: (Color r: 0.935 g: 0.935 b: 0.935).

	"Preferences takanawa."
	Preferences setPreference: #magicHalos toValue: false.
	Preferences setPreference: #magicHalos toValue: true.
	Preferences setPreference: #mouseOverHalos toValue: false.
	Preferences setPreference: #mouseOverHalos toValue: true.

	Player abandonUnnecessaryUniclasses.
	Player freeUnreferencedSubclasses.
	Player removeUninstantiatedSubclassesSilently.

	PartsBin initialize.
	Flaps disableGlobalFlaps: false.
	Flaps addAndEnableEToyFlaps.
	ActiveWorld addGlobalFlaps.
	Flaps sharedFlapsAlongBottom.

	Locale currentPlatform: (Locale isoLanguage: 'ja').
	Locale switchToID: (LocaleID isoLanguage: 'ja').
	Preferences restoreDefaultFonts.
	StrikeFont setupDefaultFallbackFont.
	Project current updateLocaleDependents.

	"Dump all projects"
	Project allSubInstancesDo:[:prj| prj == Project current ifFalse:[Project deletingProject: prj]].

	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.


! !

ReleaseBuilder subclass: #ReleaseBuilderSqueakland
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'mir 11/25/2004 17:14'!
finalCleanup
	"ReleaseBuilder new initialCleanup"


	Smalltalk abandonTempNames.
	Smalltalk zapAllOtherProjects.
	
	super finalCleanup! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'ul 1/11/2010 07:20'!
finalStripping
	"ReleaseBuilderSqueakland new finalStripping"

	#(#Helvetica #Palatino #Courier #ComicSansMS )
		do: [:n | TextConstants
				removeKey: n
				ifAbsent: []].
	Smalltalk
		at: #Player
		ifPresent: [:superCls | superCls
				allSubclassesDo: [:cls | 
					cls isSystemDefined
						ifFalse: [cls removeFromSystem].
					cls := nil]].
	Smalltalk garbageCollect.
	Smalltalk discardFFI; discardSUnit; discardSpeech.
	"discardMVC;"
	SystemOrganization removeEmptyCategories.
! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'ar 9/27/2005 21:45'!
initialCleanup
	"ReleaseBuilder new initialCleanup"

	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs| cs name ~= ChangeSet current name].

	super initialCleanup! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'md 2/24/2006 15:18'!
installPreferences

	#(
		(honorDesktopCmdKeys false)
		(warnIfNoChangesFile false)
		(warnIfNoSourcesFile false)
		(showDirectionForSketches true)
		(menuColorFromWorld false)
		(unlimitedPaintArea true)
		(useGlobalFlaps false)
		(mvcProjectsAllowed false)
		(projectViewsInWindows false)
		(automaticKeyGeneration true)
		(securityChecksEnabled true)
		(showSecurityStatus false)
		(startInUntrustedDirectory true)
		(warnAboutInsecureContent false)
		(promptForUpdateServer false)
		(fastDragWindowForMorphic false)

		(externalServerDefsOnly true)
		(expandedFormat false)
		(eToyFriendly true)
		(eToyLoginEnabled true)
		(magicHalos true)
		(mouseOverHalos true)
		(biggerHandles false)
		(selectiveHalos true)
		(includeSoundControlInNavigator true)
		(readDocumentAtStartup true)
		(preserveTrash true)
		(slideDismissalsToTrash true)
		(propertySheetFromHalo true)

	) do:[:spec|
		Preferences setPreference: spec first toValue: spec last].
	"Workaround for bug"
	Preferences enable: #readDocumentAtStartup.
! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'stephaneducasse 2/3/2006 22:24'!
installReleaseSpecifics
	"ReleaseBuilderSqueakland new installReleaseSpecifics"

	| serverName serverURL serverDir updateServer |

	ProjectLauncher splashMorph: (FileDirectory default readOnlyFileNamed: 'scripts\SqueaklandSplash.morph') fileInObjectAndCode.

	"Dump all morphs so we don't hold onto anything"
	World submorphsDo:[:m| m delete].

	World color: (Color r: 0.9 g: 0.9 b: 1.0).

	"Clear all server entries"
	ServerDirectory serverNames do: [:each | ServerDirectory removeServerNamed: each].
	SystemVersion current resetHighestUpdate.

	"Add the squeakalpha update stream"
	serverName := 'Squeakalpha'.
	serverURL := 'squeakalpha.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'updates/';
		altUrl: serverDir;
		user: 'sqland';
		password: nil.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

	"Add the squeakland update stream"
	serverName := 'Squeakland'.
	serverURL := 'squeakland.org'.
	serverDir := serverURL , '/'.

	updateServer := ServerDirectory new.
	updateServer
		server: serverURL;
		directory: 'public_html/updates/';
		altUrl: serverDir.
	Utilities updateUrlLists addFirst: {serverName. {serverDir. }.}.

! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'ar 8/6/2009 20:43'!
installVersionInfo
	"ReleaseBuilderSqueakland new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' initialAnswer: 'Squeakland 3.8.' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	(self confirm: self version , '
Is this the correct version designation?
If not, choose no, and fix it.') ifFalse: [^ self].
! !

!ReleaseBuilderSqueakland methodsFor: 'utilities' stamp: 'tak 11/28/2005 17:25'!
setupLanguageSpecifics
	"ReleaseBuilderSqueakland new setupLanguageSpecifics"
	Locale current languageEnvironment setupSqueaklandSpecifics! !

ReleaseBuilder subclass: #ReleaseBuilderTrunk
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ReleaseBuilder'!

!ReleaseBuilderTrunk class methodsFor: 'scripts' stamp: 'dtl 2/14/2010 19:53'!
prepareNewBuild "ReleaseBuilderTrunk prepareNewBuild"
	"Prepare everything that should be done for a new image build"
	Smalltalk cleanUpUndoCommands.
	Undeclared removeUnreferencedKeys.
	StandardScriptingSystem initialize.
	GradientFillStyle initPixelRampCache.
	(NaturalLanguageFormTranslator bindingOf: #CachedTranslations) value: nil.
	(NaturalLanguageTranslator bindingOf: #CachedTranslations) value: nil.
	(NaturalLanguageTranslator bindingOf: #AllKnownPhrases) value: nil.
	PaintBoxMorph classPool	at: #ColorChart put: nil.
	(Utilities bindingOf: #ScrapsBook) value: nil.
	CommandHistory resetAllHistory.
	Smalltalk at: #Browser ifPresent:[:br| br initialize].
	DataStream initialize.
	Smalltalk at: #ListParagraph ifPresent: [:lp | lp initialize].
	PopUpMenu initialize.
	Smalltalk forgetDoIts.
	Smalltalk flushClassNameCache.
	ScrollBar initializeImagesCache. 
	Behavior flushObsoleteSubclasses.
	AppRegistry withAllSubclassesDo:[:reg| reg removeObsolete].
	FileServices removeObsolete. 
	ExternalDropHandler resetRegisteredHandlers.
	SystemOrganization removeEmptyCategories.
	MCFileBasedRepository flushAllCaches.
	MCMethodDefinition shutDown.
	MCDefinition clearInstances.
	HashedCollection rehashAll.
	ChangeSet removeChangeSetsNamedSuchThat:
		[:cs| cs name ~= ChangeSet current name].
	ChangeSet current clear.
	ChangeSet current name: 'Unnamed1'.
	Smalltalk garbageCollect.
	3 timesRepeat: [ 
		Smalltalk garbageCollect. 
		Symbol compactSymbolTable.
	].! !
